//
//  DetailViewController.m
//  HA7 logger mini04
//  Copyright(C)2012-2013 Toyohiko Togashi tog001@nifty.com
//
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//    Update history
//    ---------- ----- -------------------------------------------
//    2013.05.11 v0.4  First cording
//    2013.05.11 v0.4  Detail information, route map
//
#import "DetailViewController.h"

#define MIN_DIST    0.0001          // ~=10m
#define SKIP_COUNT  10              // ~=10s
#define MAX_POINT   360             // ~=1h

@interface DetailViewController ()  <MKMapViewDelegate>

@end


@implementation DetailViewController


- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}


- (void)viewDidLoad
{
    [super viewDidLoad];
    self.map.delegate = self;
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}


- (void)viewWillAppear:(BOOL)animated
{
    // Date
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateStyle:NSDateFormatterMediumStyle];
    [self.deb setText:[dateFormatter stringFromDate:self.showDate]];

    // Map
    NSDateComponents *dc = [[NSCalendar currentCalendar] components:NSYearCalendarUnit|NSMonthCalendarUnit|NSDayCalendarUnit fromDate:self.showDate];
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *path1 = [[NSString alloc] initWithFormat:@"%@/%d-%02d-%02d.csv",[paths objectAtIndex:0],dc.year,dc.month,dc.day];
    const char *fname = [path1 UTF8String];
    FILE *fp = fopen(fname,"r");
    if (fp != NULL) {
        CLLocationCoordinate2D points[MAX_POINT];
        int     pintNum;
        int     sc;
        double  c1;
        double  c2;
        double  c1_max;
        double  c2_max;
        double  c1_min;
        double  c2_min;
        char    buff[300];
        
        pintNum = 0;
        c1      = 0.0;
        c2      = 0.0;
        sc      = 1;        // Header line
        while(fgets(buff, sizeof(buff), fp) != NULL) {
            char    *k;
            char    *kk;
            int     i;
            double  c11;
            double  c22;
            
            if (--sc >= 0) {
                continue;
            }
            c11 = 0.0;
            c22 = 0.0;
            for(k = strtok_r(buff, ",", &kk), i = 0; k != NULL; k = strtok_r(NULL, ",", &kk), i++) {
                if (i == 20) {
                    c11 = atof(k);
                } else if (i == 21) {
                    c22 = atof(k);
                }
            }
            if ((c11 == 0.0) || (c22 == 0.0)) { // Data error
                continue;
            }
            if (sqrt(pow(c11 - c1, 2.0) + pow(c22 - c2, 2.0)) > MIN_DIST) {
                c1 = c11;
                c2 = c22;
                points[pintNum].latitude  = c1;
                points[pintNum].longitude = c2;
                if (pintNum == 0) {
                    c1_max = c1;
                    c2_max = c2;
                    c1_min = c1;
                    c2_min = c2;
                } else {
                    c1_max = MAX(c1_max, c1);
                    c2_max = MAX(c2_max, c2);
                    c2_min = MIN(c2_min, c2);
                    c1_min = MIN(c1_min, c1);
                }
                if (++pintNum >= MAX_POINT) {
                    break;
                }
            }
            sc = SKIP_COUNT;
        }
        fclose(fp);
        
        if (pintNum > 1) {
            MKPolyline * poly = [MKPolyline polylineWithCoordinates:points count:pintNum];
            poly.title = @"Route";
            [self.map addOverlay:poly];
            
            MKCoordinateRegion theRegion = [self.map region];
            theRegion.center.latitude     = (c1_max + c1_min) / 2.0;
            theRegion.center.longitude    = (c2_max + c2_min) / 2.0;
            theRegion.span.latitudeDelta  = (c1_max - c1_min) * 1.2;
            theRegion.span.longitudeDelta = (c2_max - c2_min) * 1.2;
            [self.map setRegion:theRegion animated:YES];
        }
    }
}


- (IBAction)closeMyView:(id)sender
{
    [[self presentingViewController] dismissViewControllerAnimated:YES completion:nil];
}


#pragma mark - Map View Delegate


- (MKOverlayView *)mapView:(MKMapView *)mapView viewForOverlay:(id <MKOverlay>)overlay
{
    if ([overlay isKindOfClass:[MKPolyline class]]) {
        MKPolylineView*    aView = [[MKPolylineView alloc] initWithPolyline:(MKPolyline *)overlay];
        aView.lineWidth   = 5;
        if (aView.polyline.pointCount < MAX_POINT) {
            aView.strokeColor = [UIColor blueColor];
        } else {
            aView.strokeColor = [UIColor orangeColor];
        }
        return aView;
    }
    return nil;
}

@end
