//
//  SecondViewController.m
//  HA7 logger mini04
//  Copyright(C)2012-2013 Toyohiko Togashi tog001@nifty.com
//
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//    Update history
//    ---------- ----- -------------------------------------------
//    2013.03.25 v0.0  First cording
//    2013.05.04 v0.4  Commit
//

#import "SecondViewController.h"
#import "AppDelegate.h"

#define FUEL_TANK    37.0
#define EFF_LIMIT    30.0

@interface SecondViewController ()
@property (weak, nonatomic)     ObdDataLogger   *obd;
@property (strong, nonatomic)   NSTimer         *updateTimer;
@property (nonatomic)           int             stopTm;
@property (nonatomic)           enum {INIT,CONNECT,DISCONNECT} connectStat;
@end


@implementation SecondViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    AppDelegate *appDeligate = [[UIApplication sharedApplication] delegate];
    self.obd         = appDeligate.obd;
    self.connectStat = INIT;
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}


- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
 	self.updateTimer = [NSTimer scheduledTimerWithTimeInterval:1.0 target:self selector:@selector(refreshView:) userInfo:nil repeats:YES];
}


- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [self.updateTimer invalidate];
    [UIApplication sharedApplication].idleTimerDisabled = NO;
    self.tabBarItem.badgeValue = nil;
}


- (IBAction)refreshView:(id)sender
{
    if (self.obd.valid) {
        if (self.obd.dist > 0.001) {   // 1[m/s]
            self.stopTm = 0;
        } else {
            self.stopTm++;
        }
        [self.vss setText:[[NSString alloc] initWithFormat:@"%d",self.obd.vss]];
        [self.rpm setText:[[NSString alloc] initWithFormat:@"%d",self.obd.rpm]];
        [self.rpmG setIntValue:self.obd.rpm];

        [self.effNow setText:[[NSString alloc] initWithFormat:@"%.1f",self.obd.eff]];
        [self.effDay setText:[[NSString alloc] initWithFormat:@"%.1f",self.obd.eff_d]];
        [self.effAve setText:[[NSString alloc] initWithFormat:@"%.1f",self.obd.eff_s]];
        [self.effNowG setFloatValue:self.obd.eff];
        [self.effDayG setFloatValue:self.obd.eff_d];
        [self.effAveG setFloatValue:self.obd.eff_s];

        [self.stopTim   setText:[[NSString alloc] initWithFormat:@"%d:%02d",self.stopTm/60, self.stopTm%60]];
        [self.fuse_d    setText:[[NSString alloc] initWithFormat:@"%.2f",self.obd.fuse_d]];
        [self.dist_d    setText:[[NSString alloc] initWithFormat:@"%.2f",self.obd.dist_d]];
        [self.runtmDay  setText:[[NSString alloc] initWithFormat:@"%ld:%02ld",self.obd.runtm_d/60, self.obd.runtm_d%60]];
        [self.runtmDayG setProgress:((double)self.obd.movtm_d/(double)self.obd.runtm_d)];

        [self.remainFuel  setText:[[NSString alloc] initWithFormat:@"%.2f",self.obd.remainFuel]];
        [self.remainFuelG setProgress:(self.obd.remainFuel/FUEL_TANK)];
        [self.remainDist setText:[[NSString alloc] initWithFormat:@"%d",(int)(self.obd.remainFuel * self.obd.eff_s)]];
        [self.ect setText:[[NSString alloc] initWithFormat:@"%d",self.obd.ect]];
        [self.ectG setProgress:((self.obd.ect + 30.0)/130.0)];
        [self.vpwr setText:[[NSString alloc] initWithFormat:@"%.1f",(float)self.obd.vpwr/1000.0]];
        [self.vpwrG setProgress:((self.obd.vpwr - 11000)/4000.0)];

        if (self.connectStat != CONNECT) {
            [UIApplication sharedApplication].idleTimerDisabled = YES;
            self.tabBarItem.badgeValue = nil;
            self.connectStat = CONNECT;
        }
    } else {
        if (self.connectStat != DISCONNECT) {
            [UIApplication sharedApplication].idleTimerDisabled = NO;
            self.tabBarItem.badgeValue = @"X";
            self.connectStat = DISCONNECT;
        }
    }
}


- (IBAction)refuel:(id)sender
{
    self.obd.remainFuel = FUEL_TANK;
}

@end
