//
//  ThirdViewController.m
//  HA7 logger mini04
//  Copyright(C)2012-2013 Toyohiko Togashi tog001@nifty.com
//
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//    Update history
//    ---------- ----- -------------------------------------------
//    2013.04.29 v0.0  First cording
//    2013.05.04 v0.4  Commit
//    2013.05.11 v0.4  Detail information, route map
//
#import "ThirdViewController.h"
#import "CalendarViewCell.h"
#import "DetailViewController.h"

@interface ThirdViewController ()
@property (strong, nonatomic)   NSDate           *calendarTopDate;
@property (strong, nonatomic)   UICollectionView *cv;
@end


@implementation ThirdViewController


// Internal function
- (void)changeCalendarTopDate:(NSDate *)calendarTopDate
{
    self.calendarTopDate = calendarTopDate;
    NSDate *ym = [[NSDate alloc] initWithTimeInterval:24*60*60*7 sinceDate:self.calendarTopDate];
    NSDateComponents *ymComps = [[NSCalendar currentCalendar] components:NSYearCalendarUnit | NSMonthCalendarUnit fromDate:ym];
    [self.yyyymm setText:[[NSString alloc] initWithFormat:@"%d/%d", ymComps.year, ymComps.month]];
}


- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}


- (void)viewDidLoad
{
    [super viewDidLoad];

    NSDate *now = [[NSDate alloc] init];
    NSDateComponents *nowComps = [[NSCalendar currentCalendar] components:NSYearCalendarUnit|NSMonthCalendarUnit|NSDayCalendarUnit|NSWeekdayCalendarUnit fromDate:now];
    NSDate *calTop = [[NSDate alloc] initWithTimeInterval:-24*60*60*((nowComps.day-nowComps.weekday+6)/ 7 * 7 +nowComps.weekday - 1) sinceDate:now];
    [self changeCalendarTopDate:calTop];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];    
}


- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
}


- (NSInteger)collectionView:(UICollectionView *)view numberOfItemsInSection:(NSInteger)section
{
    self.cv = view;
    return 7*6;
}


- (UICollectionViewCell *)collectionView:(UICollectionView *)cv cellForItemAtIndexPath:(NSIndexPath *)indexPath
{

    CalendarViewCell *cell = [cv dequeueReusableCellWithReuseIdentifier:@"cellID" forIndexPath:indexPath];
    NSDate *d = [[NSDate alloc] initWithTimeInterval:24*60*60*indexPath.row sinceDate:self.calendarTopDate];
    NSDateComponents *dc = [[NSCalendar currentCalendar] components:NSYearCalendarUnit|NSMonthCalendarUnit|NSDayCalendarUnit fromDate:d];
    [cell.monthOfdate setText:[NSString stringWithFormat:@"%d",dc.day]];

    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *path1 = [[NSString alloc] initWithFormat:@"%@/%d-%02d-%02d.csv",[paths objectAtIndex:0],dc.year,dc.month,dc.day];
    const char *fname = [path1 UTF8String];
    FILE *fp = fopen(fname,"r");
    if (fp != NULL) {
        char    buff[300];
        char    *p;
        char    *pp;
        int     i;
        double  dist_b;
        double  fuse_b;
        double  dist_e;
        double  fuse_e;
        double  dist;
        double  fuse;
        float   eff;
        
        fgets(buff, sizeof(buff), fp);
        fgets(buff, sizeof(buff), fp);
        for(p = strtok_r(buff, ",", &pp), i = 0; p != NULL; p = strtok_r(NULL, ",", &pp), i++) {
            if (i == 16) {
                dist_b = atof(p);
            } else if (i == 17) {
                fuse_b = atof(p);
            }
        }
        fseek(fp, -400L, SEEK_END);
        fgets(buff, sizeof(buff), fp);
        fgets(buff, sizeof(buff), fp);
        for(p = strtok_r(buff, ",", &pp), i = 0; p != NULL; p = strtok_r(NULL, ",", &pp), i++) {
            if (i == 16) {
                dist_e = atof(p);
            } else if (i == 17) {
                fuse_e = atof(p);
            }
        }
        fclose(fp);
        dist = dist_e - dist_b;
        fuse = fuse_e - fuse_b;
        if ((dist_e >= 0.0) && (fuse > 0.0)) {
            eff = dist / fuse;
        } else {
            eff = 0.0;
        }
        switch(self.item.selectedSegmentIndex){
            case 0:
                [cell.value setText:[NSString stringWithFormat:@"%.1f",eff]];
                break;
            case 1:
                [cell.value setText:[NSString stringWithFormat:@"%.1f",fuse]];
                break;
            case 2:
                [cell.value setText:[NSString stringWithFormat:@"%.1f",dist]];
                break;
            default:
                break;
        }
    } else {
        [cell.value setText:nil];
    }

    if ((indexPath.row < 7) && (dc.day > 7)) {
        cell.monthOfdate.alpha = 0.3;
        cell.value.alpha       = 0.3;
    } else if ((indexPath.row > 28) && (dc.day < 15)) {
        cell.monthOfdate.alpha = 0.3;
        cell.value.alpha       = 0.3;
    } else {
        cell.monthOfdate.alpha = 1.0;
        cell.value.alpha       = 1.0;
    }
    return cell;
}


- (IBAction)nextMonth:(id)sender
{
    NSDate *ym = [[NSDate alloc] initWithTimeInterval:24*60*60*42 sinceDate:self.calendarTopDate];
    NSDateComponents *nowComps = [[NSCalendar currentCalendar] components:NSYearCalendarUnit|NSMonthCalendarUnit|NSDayCalendarUnit|NSWeekdayCalendarUnit fromDate:ym];
    NSDate *calTop = [[NSDate alloc] initWithTimeInterval:-24*60*60*((nowComps.day-nowComps.weekday+6)/ 7 * 7 +nowComps.weekday - 1) sinceDate:ym];
    NSDate *today = [[NSDate alloc] init];
    if ([calTop compare:today] == NSOrderedAscending) {
        [self changeCalendarTopDate:calTop];
        [self.cv reloadData];
    }
}


- (IBAction)prevMonth:(id)sender
{
    NSDate *ym = [[NSDate alloc] initWithTimeInterval:-24*60*60*7 sinceDate:self.calendarTopDate];
    NSDateComponents *nowComps = [[NSCalendar currentCalendar] components:NSYearCalendarUnit|NSMonthCalendarUnit|NSDayCalendarUnit|NSWeekdayCalendarUnit fromDate:ym];
    NSDate *calTop = [[NSDate alloc] initWithTimeInterval:-24*60*60*((nowComps.day-nowComps.weekday+6)/ 7 * 7 +nowComps.weekday - 1) sinceDate:ym];
    [self changeCalendarTopDate:calTop];
    [self.cv reloadData];
}


- (IBAction)changeItem:(id)sender
{
    [self.cv reloadData];
}


- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([[segue identifier] isEqualToString:@"showDetail"]){
        NSIndexPath *selectedIndexPath = [[self.cv indexPathsForSelectedItems] objectAtIndex:0];
        NSDate *d = [[NSDate alloc] initWithTimeInterval:24*60*60*selectedIndexPath.row sinceDate:self.calendarTopDate];

        DetailViewController *detailViewController = [segue destinationViewController];
        detailViewController.showDate = d;
    }
}


@end
